/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.javagnome.Handle;

/**
 *
 */
public class EventSelection extends Event
{
    /**
     * Promotion constructor. Construct the specific event object by
     * promoting (sharing the <tt>Handle</tt> object of) the base
     * <tt>Event</tt>.
     */
    public EventSelection( Event evt ) {
        // We share the handle with both instances.  This avoids
        // copying the event (via the constructor ( super( evt ) ).
        // It is more of a "promotion" constructor.
        super( evt.getHandle() );
    }

    native static final protected Handle getWindow (Handle obj);
    native static final protected boolean getSendEvent (Handle obj);
    native static final protected int getSelection (Handle obj);
    native static final protected int getTarget (Handle obj);
    native static final protected int getProperty (Handle obj);
    native static final protected Handle getRequestor (Handle obj);
    native static final protected int getTime (Handle obj);
}

